##!/usr/bin/env python
# -*- coding: utf-8 -*-

from PyQt4 import QtGui, QtCore
from PyQt4.QtCore import Qt
import sys
import PyQt4


class TestModelItem( object ):

    def __init__(self, code, description ):
        self.code = code
        self.description = description

    def childCount(self):
        return 0

    def data(self, index, role):
        if role in ( Qt.DisplayRole, Qt.EditRole ):
            return self.code if index == 0 else self.description

        return QtCore.QVariant()


class TestModel( QtCore.QAbstractItemModel ):

    COLUMNS = ( "Code", "Description" )

    def __init__(self):
        self.items = [
            TestModelItem( "1", "aaaaaa" ),
            TestModelItem( "2", "bbbbbb" ),
            TestModelItem( "3", "cccccc" ),
            TestModelItem( "4", "dddddd" ),
        ]

        super( TestModel, self ).__init__()

    def index(self, row, column, parent):
        return self.createIndex( row, column, self.items[ row ] )

    def rowCount(self, parent):
        return 0 if parent.isValid() else len( self.items )

    def columnCount(self, parent):
        return len( self.COLUMNS )

    def widget(self, index):
        return QtCore.QModelIndex()

    def headerData(self, section, orientation, role):
        if orientation == Qt.Horizontal and role == Qt.DisplayRole:
            return self.COLUMNS[ section ]

        return None

    def data(self, index, role):
        if index.isValid():
            return index.internalPointer().data( index.column(), role )
        else:
            return super( TestModel, self ).data( index, role )

    def parent(self, index):
        return QtCore.QModelIndex()


class MainWindow( QtGui.QMainWindow ):

    def __init__(self):
        super( MainWindow, self ).__init__()

        self.widget = QtGui.QWidget( self )
        self.combo = QtGui.QComboBox( self.widget )
        self.view = QtGui.QTreeView( self.combo )
        self.edit = QtGui.QCheckBox( self.widget )

#        self.combo.resize( QtCore.QSize( 200, self.combo.size().height() ) )
        self.setCentralWidget( self.widget )
        self.combo.setModel( TestModel() )
        self.combo.setView( self.view )

        self.view.header().setResizeMode( 0, QtGui.QHeaderView.ResizeToContents )
        self.view.header().setResizeMode( 1, QtGui.QHeaderView.ResizeToContents )

        self.connect(
            self.edit, QtCore.SIGNAL( "stateChanged(int)" ),
            self.on_state_changed_signal
        )

        layout = QtGui.QVBoxLayout( self.widget )

        layout.addWidget( self.combo )
        layout.addWidget( self.edit )

    @QtCore.pyqtSlot(int)
    def on_state_changed_signal(self, value):
        self.combo.setEditable( self.edit.isChecked() )


if __name__ == '__main__':
    app = QtGui.QApplication( sys.argv )

    main = MainWindow()

    main.show()

    app.exec_()